==> axiom-1.3.0-src.zip: axiom-1.3.0/components/core-streams/src/main/java/org/apache/axiom/core/stream/NamespaceRepairingFilter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.core.stream;

public final class NamespaceRepairingFilter implements XmlFilter {
    public static final NamespaceRepairingFilter DEFAULT = new NamespaceRepairingFilter(null, false);

    private final NamespaceContextProvider parentNamespaceContext;
    private final boolean removeRedundantDeclarations;

    public NamespaceRepairingFilter(NamespaceContextProvider parentNamespaceContext,
            boolean removeRedundantDeclarations) {
        this.parentNamespaceContext = parentNamespaceContext;
        this.removeRedundantDeclarations = removeRedundantDeclarations;
    }

    @Override
    public XmlHandler createFilterHandler(XmlHandler parent) {
        return new NamespaceRepairingFilterHandler(parent, parentNamespaceContext,
                removeRedundantDeclarations);
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/components/core-streams/src/main/java/org/apache/axiom/core/stream/NamespaceRepairingFilter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.core.stream;

public final class NamespaceRepairingFilter implements XmlFilter {
    public static final NamespaceRepairingFilter DEFAULT =
            new NamespaceRepairingFilter(null, false);

    private final NamespaceContextProvider parentNamespaceContext;
    private final boolean removeRedundantDeclarations;

    public NamespaceRepairingFilter(
            NamespaceContextProvider parentNamespaceContext, boolean removeRedundantDeclarations) {
        this.parentNamespaceContext = parentNamespaceContext;
        this.removeRedundantDeclarations = removeRedundantDeclarations;
    }

    @Override
    public XmlHandler createFilterHandler(XmlHandler parent) {
        return new NamespaceRepairingFilterHandler(
                parent, parentNamespaceContext, removeRedundantDeclarations);
    }
}
